@@ -9,7 +9,7 @@ use Time::Local qw/timelocal_nocheck/;
 BEGIN {
 	use Exporter ();
 	use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-	$VERSION     = 0.02;
+	$VERSION     = 0.03;
 	@ISA         = qw (Exporter);
 	#Give a hoot don't pollute, do not export more than needed by default
 	@EXPORT      = qw ();
@@ -359,7 +359,7 @@ sub between {
         return(-1);
     }
 
-    my $period = Set::IntSpan($start."-".$end);
+    my $period = Set::IntSpan->new($start."-".$end);
     my $intersection = intersect $period $self->{'calculated'};
 
     return cardinality $intersection;
